@@ -1,7 +1,7 @@
 
 package Net::LDAP::ASN;
 
-$VERSION = "0.05";
+$VERSION = "0.06";
 
 use Convert::ASN1;
 
@@ -433,6 +433,12 @@ $asn->prepare(<<LDAP_ASN) or die $asn->error;
 	type            [2] AttributeDescription OPTIONAL,
 	--- at least one of the above must be present
 	matchValue      [3] AssertionValue }
+
+    -- RFC-4527 Pre-/Post-read Control
+    -- note: this is SearchResultEntry without the APPLICATION tag
+    prSearchResultEntry ::= SEQUENCE {
+	objectName      LDAPDN,
+	attributes      PartialAttributeList }
     
 LDAP_ASN
 
