@@ -19,9 +19,11 @@ use Net::LDAP::Constant qw(
   LDAP_CONTROL_ENTRYCHANGE
   LDAP_CONTROL_MATCHEDVALUES
   LDAP_CONTROL_PASSWORDPOLICY
+  LDAP_CONTROL_PREREAD
+  LDAP_CONTROL_POSTREAD
 );
 
-$VERSION = "0.07";
+$VERSION = "0.08";
 
 my %Pkg2Type = (
 
@@ -43,6 +45,10 @@ my %Pkg2Type = (
   'Net::LDAP::Control::MatchedValues'	=> LDAP_CONTROL_MATCHEDVALUES,
 
   'Net::LDAP::Control::PasswordPolicy'	=> LDAP_CONTROL_PASSWORDPOLICY,
+
+  'Net::LDAP::Control::PreRead'		=> LDAP_CONTROL_PREREAD,
+
+  'Net::LDAP::Control::PostRead'	=> LDAP_CONTROL_POSTREAD,
   #
   #LDAP_CONTROL_PWEXPIRED
   #LDAP_CONTROL_PWEXPIRING
